==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/DirectLineSiteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.DirectLineSiteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A site for the Direct Line channel
 * @property appId DirectLine application id
 * @property eTag Entity Tag
 * @property isBlockUserUploadEnabled Whether this site is enabled for block user upload.
 * @property isDetailedLoggingEnabled Whether this site is disabled detailed logging for
 * @property isEnabled Whether this site is enabled for DirectLine channel
 * @property isEndpointParametersEnabled Whether this site is EndpointParameters enabled for channel
 * @property isNoStorageEnabled Whether this no-storage site is disabled detailed logging for
 * @property isSecureSiteEnabled Whether this site is enabled for authentication with Bot Framework.
 * @property isV1Enabled Whether this site is enabled for Bot Framework V1 protocol.
 * @property isV3Enabled Whether this site is enabled for Bot Framework V3 protocol.
 * @property isWebChatSpeechEnabled Whether this site is enabled for Webchat Speech
 * @property isWebchatPreviewEnabled Whether this site is enabled for preview versions of Webchat
 * @property siteName Site name
 * @property tenantId Tenant Id
 * @property trustedOrigins List of Trusted Origin URLs for this site. This field is applicable only if isSecureSiteEnabled is True.
 */
public data class DirectLineSiteArgs(
    public val appId: Output<String>? = null,
    public val eTag: Output<String>? = null,
    public val isBlockUserUploadEnabled: Output<Boolean>? = null,
    public val isDetailedLoggingEnabled: Output<Boolean>? = null,
    public val isEnabled: Output<Boolean>,
    public val isEndpointParametersEnabled: Output<Boolean>? = null,
    public val isNoStorageEnabled: Output<Boolean>? = null,
    public val isSecureSiteEnabled: Output<Boolean>? = null,
    public val isV1Enabled: Output<Boolean>,
    public val isV3Enabled: Output<Boolean>,
    public val isWebChatSpeechEnabled: Output<Boolean>? = null,
    public val isWebchatPreviewEnabled: Output<Boolean>? = null,
    public val siteName: Output<String>,
    public val tenantId: Output<String>? = null,
    public val trustedOrigins: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.DirectLineSiteArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.DirectLineSiteArgs =
        com.pulumi.azurenative.botservice.inputs.DirectLineSiteArgs.builder()
            .appId(appId?.applyValue({ args0 -> args0 }))
            .eTag(eTag?.applyValue({ args0 -> args0 }))
            .isBlockUserUploadEnabled(isBlockUserUploadEnabled?.applyValue({ args0 -> args0 }))
            .isDetailedLoggingEnabled(isDetailedLoggingEnabled?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 }))
            .isEndpointParametersEnabled(isEndpointParametersEnabled?.applyValue({ args0 -> args0 }))
            .isNoStorageEnabled(isNoStorageEnabled?.applyValue({ args0 -> args0 }))
            .isSecureSiteEnabled(isSecureSiteEnabled?.applyValue({ args0 -> args0 }))
            .isV1Enabled(isV1Enabled.applyValue({ args0 -> args0 }))
            .isV3Enabled(isV3Enabled.applyValue({ args0 -> args0 }))
            .isWebChatSpeechEnabled(isWebChatSpeechEnabled?.applyValue({ args0 -> args0 }))
            .isWebchatPreviewEnabled(isWebchatPreviewEnabled?.applyValue({ args0 -> args0 }))
            .siteName(siteName.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 }))
            .trustedOrigins(trustedOrigins?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DirectLineSiteArgs].
 */
@PulumiTagMarker
public class DirectLineSiteArgsBuilder internal constructor() {
    private var appId: Output<String>? = null

    private var eTag: Output<String>? = null

    private var isBlockUserUploadEnabled: Output<Boolean>? = null

    private var isDetailedLoggingEnabled: Output<Boolean>? = null

    private var isEnabled: Output<Boolean>? = null

    private var isEndpointParametersEnabled: Output<Boolean>? = null

    private var isNoStorageEnabled: Output<Boolean>? = null

    private var isSecureSiteEnabled: Output<Boolean>? = null

    private var isV1Enabled: Output<Boolean>? = null

    private var isV3Enabled: Output<Boolean>? = null

    private var isWebChatSpeechEnabled: Output<Boolean>? = null

    private var isWebchatPreviewEnabled: Output<Boolean>? = null

    private var siteName: Output<String>? = null

    private var tenantId: Output<String>? = null

    private var trustedOrigins: Output<List<String>>? = null

    /**
     * @param value DirectLine application id
     */
    @JvmName("kjmwwtxvjxcklqke")
    public suspend fun appId(`value`: Output<String>) {
        this.appId = value
    }

    /**
     * @param value Entity Tag
     */
    @JvmName("ukjdkfkaigkpsngi")
    public suspend fun eTag(`value`: Output<String>) {
        this.eTag = value
    }

    /**
     * @param value Whether this site is enabled for block user upload.
     */
    @JvmName("yofifgabafoxccxv")
    public suspend fun isBlockUserUploadEnabled(`value`: Output<Boolean>) {
        this.isBlockUserUploadEnabled = value
    }

    /**
     * @param value Whether this site is disabled detailed logging for
     */
    @JvmName("ekixfndsbtefllsf")
    public suspend fun isDetailedLoggingEnabled(`value`: Output<Boolean>) {
        this.isDetailedLoggingEnabled = value
    }

    /**
     * @param value Whether this site is enabled for DirectLine channel
     */
    @JvmName("bubfdoonqtwycqkc")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Whether this site is EndpointParameters enabled for channel
     */
    @JvmName("jgagkpmykogvibbu")
    public suspend fun isEndpointParametersEnabled(`value`: Output<Boolean>) {
        this.isEndpointParametersEnabled = value
    }

    /**
     * @param value Whether this no-storage site is disabled detailed logging for
     */
    @JvmName("ccvrbgbltvjgehbg")
    public suspend fun isNoStorageEnabled(`value`: Output<Boolean>) {
        this.isNoStorageEnabled = value
    }

    /**
     * @param value Whether this site is enabled for authentication with Bot Framework.
     */
    @JvmName("xqpakxwstfucytmp")
    public suspend fun isSecureSiteEnabled(`value`: Output<Boolean>) {
        this.isSecureSiteEnabled = value
    }

    /**
     * @param value Whether this site is enabled for Bot Framework V1 protocol.
     */
    @JvmName("envfhitlousutjvm")
    public suspend fun isV1Enabled(`value`: Output<Boolean>) {
        this.isV1Enabled = value
    }

    /**
     * @param value Whether this site is enabled for Bot Framework V3 protocol.
     */
    @JvmName("faakpddqrmdtwhsd")
    public suspend fun isV3Enabled(`value`: Output<Boolean>) {
        this.isV3Enabled = value
    }

    /**
     * @param value Whether this site is enabled for Webchat Speech
     */
    @JvmName("lqlrpqwnuhvnunjl")
    public suspend fun isWebChatSpeechEnabled(`value`: Output<Boolean>) {
        this.isWebChatSpeechEnabled = value
    }

    /**
     * @param value Whether this site is enabled for preview versions of Webchat
     */
    @JvmName("bjbdnftncsxtscgn")
    public suspend fun isWebchatPreviewEnabled(`value`: Output<Boolean>) {
        this.isWebchatPreviewEnabled = value
    }

    /**
     * @param value Site name
     */
    @JvmName("cboplagqltvegpvj")
    public suspend fun siteName(`value`: Output<String>) {
        this.siteName = value
    }

    /**
     * @param value Tenant Id
     */
    @JvmName("uingmlhldstejwuu")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value List of Trusted Origin URLs for this site. This field is applicable only if isSecureSiteEnabled is True.
     */
    @JvmName("toruyklbyxbgpanm")
    public suspend fun trustedOrigins(`value`: Output<List<String>>) {
        this.trustedOrigins = value
    }

    @JvmName("sefstcwxkyucpwxp")
    public suspend fun trustedOrigins(vararg values: Output<String>) {
        this.trustedOrigins = Output.all(values.asList())
    }

    /**
     * @param values List of Trusted Origin URLs for this site. This field is applicable only if isSecureSiteEnabled is True.
     */
    @JvmName("sdbtafjcxqbiirsy")
    public suspend fun trustedOrigins(values: List<Output<String>>) {
        this.trustedOrigins = Output.all(values)
    }

    /**
     * @param value DirectLine application id
     */
    @JvmName("sihhawcnogilejxb")
    public suspend fun appId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.appId = mapped
    }

    /**
     * @param value Entity Tag
     */
    @JvmName("spnkkgvrbguwlbdi")
    public suspend fun eTag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eTag = mapped
    }

    /**
     * @param value Whether this site is enabled for block user upload.
     */
    @JvmName("gjlwevvdimtuekgc")
    public suspend fun isBlockUserUploadEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isBlockUserUploadEnabled = mapped
    }

    /**
     * @param value Whether this site is disabled detailed logging for
     */
    @JvmName("gwwbmxribhcmfaes")
    public suspend fun isDetailedLoggingEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isDetailedLoggingEnabled = mapped
    }

    /**
     * @param value Whether this site is enabled for DirectLine channel
     */
    @JvmName("xbsuixajbjgcvvjp")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value Whether this site is EndpointParameters enabled for channel
     */
    @JvmName("hjfhfmgbwpydhgah")
    public suspend fun isEndpointParametersEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEndpointParametersEnabled = mapped
    }

    /**
     * @param value Whether this no-storage site is disabled detailed logging for
     */
    @JvmName("pqlcbqngswfsaqgd")
    public suspend fun isNoStorageEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isNoStorageEnabled = mapped
    }

    /**
     * @param value Whether this site is enabled for authentication with Bot Framework.
     */
    @JvmName("pbkvishckmbkqkyr")
    public suspend fun isSecureSiteEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isSecureSiteEnabled = mapped
    }

    /**
     * @param value Whether this site is enabled for Bot Framework V1 protocol.
     */
    @JvmName("jldrckqknkuuodrs")
    public suspend fun isV1Enabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isV1Enabled = mapped
    }

    /**
     * @param value Whether this site is enabled for Bot Framework V3 protocol.
     */
    @JvmName("bvhnahntbwyurkah")
    public suspend fun isV3Enabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isV3Enabled = mapped
    }

    /**
     * @param value Whether this site is enabled for Webchat Speech
     */
    @JvmName("njbxfaltutcdyrgu")
    public suspend fun isWebChatSpeechEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isWebChatSpeechEnabled = mapped
    }

    /**
     * @param value Whether this site is enabled for preview versions of Webchat
     */
    @JvmName("cbefdlhpmnhpbsqj")
    public suspend fun isWebchatPreviewEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isWebchatPreviewEnabled = mapped
    }

    /**
     * @param value Site name
     */
    @JvmName("mugsynalltdrgsow")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.siteName = mapped
    }

    /**
     * @param value Tenant Id
     */
    @JvmName("otfotsxmrctnanii")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    /**
     * @param value List of Trusted Origin URLs for this site. This field is applicable only if isSecureSiteEnabled is True.
     */
    @JvmName("ukdoasekubbhuxoe")
    public suspend fun trustedOrigins(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustedOrigins = mapped
    }

    /**
     * @param values List of Trusted Origin URLs for this site. This field is applicable only if isSecureSiteEnabled is True.
     */
    @JvmName("cxcatovapuimglpg")
    public suspend fun trustedOrigins(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trustedOrigins = mapped
    }

    internal fun build(): DirectLineSiteArgs = DirectLineSiteArgs(
        appId = appId,
        eTag = eTag,
        isBlockUserUploadEnabled = isBlockUserUploadEnabled,
        isDetailedLoggingEnabled = isDetailedLoggingEnabled,
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
        isEndpointParametersEnabled = isEndpointParametersEnabled,
        isNoStorageEnabled = isNoStorageEnabled,
        isSecureSiteEnabled = isSecureSiteEnabled,
        isV1Enabled = isV1Enabled ?: throw PulumiNullFieldException("isV1Enabled"),
        isV3Enabled = isV3Enabled ?: throw PulumiNullFieldException("isV3Enabled"),
        isWebChatSpeechEnabled = isWebChatSpeechEnabled,
        isWebchatPreviewEnabled = isWebchatPreviewEnabled,
        siteName = siteName ?: throw PulumiNullFieldException("siteName"),
        tenantId = tenantId,
        trustedOrigins = trustedOrigins,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/DirectLineSiteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.DirectLineSiteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A site for the Direct Line channel
 * @property appId DirectLine application id
 * @property eTag Entity Tag
 * @property isBlockUserUploadEnabled Whether this site is enabled for block user upload.
 * @property isDetailedLoggingEnabled Whether this site is disabled detailed logging for
 * @property isEnabled Whether this site is enabled for DirectLine channel
 * @property isEndpointParametersEnabled Whether this site is EndpointParameters enabled for channel
 * @property isNoStorageEnabled Whether this no-storage site is disabled detailed logging for
 * @property isSecureSiteEnabled Whether this site is enabled for authentication with Bot Framework.
 * @property isV1Enabled Whether this site is enabled for Bot Framework V1 protocol.
 * @property isV3Enabled Whether this site is enabled for Bot Framework V3 protocol.
 * @property isWebChatSpeechEnabled Whether this site is enabled for Webchat Speech
 * @property isWebchatPreviewEnabled Whether this site is enabled for preview versions of Webchat
 * @property siteName Site name
 * @property tenantId Tenant Id
 * @property trustedOrigins List of Trusted Origin URLs for this site. This field is applicable only if isSecureSiteEnabled is True.
 */
public data class DirectLineSiteArgs(
    public val appId: Output<String>? = null,
    public val eTag: Output<String>? = null,
    public val isBlockUserUploadEnabled: Output<Boolean>? = null,
    public val isDetailedLoggingEnabled: Output<Boolean>? = null,
    public val isEnabled: Output<Boolean>,
    public val isEndpointParametersEnabled: Output<Boolean>? = null,
    public val isNoStorageEnabled: Output<Boolean>? = null,
    public val isSecureSiteEnabled: Output<Boolean>? = null,
    public val isV1Enabled: Output<Boolean>,
    public val isV3Enabled: Output<Boolean>,
    public val isWebChatSpeechEnabled: Output<Boolean>? = null,
    public val isWebchatPreviewEnabled: Output<Boolean>? = null,
    public val siteName: Output<String>,
    public val tenantId: Output<String>? = null,
    public val trustedOrigins: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.DirectLineSiteArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.DirectLineSiteArgs =
        com.pulumi.azurenative.botservice.inputs.DirectLineSiteArgs.builder()
            .appId(appId?.applyValue({ args0 -> args0 }))
            .eTag(eTag?.applyValue({ args0 -> args0 }))
            .isBlockUserUploadEnabled(isBlockUserUploadEnabled?.applyValue({ args0 -> args0 }))
            .isDetailedLoggingEnabled(isDetailedLoggingEnabled?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 }))
            .isEndpointParametersEnabled(isEndpointParametersEnabled?.applyValue({ args0 -> args0 }))
            .isNoStorageEnabled(isNoStorageEnabled?.applyValue({ args0 -> args0 }))
            .isSecureSiteEnabled(isSecureSiteEnabled?.applyValue({ args0 -> args0 }))
            .isV1Enabled(isV1Enabled.applyValue({ args0 -> args0 }))
            .isV3Enabled(isV3Enabled.applyValue({ args0 -> args0 }))
            .isWebChatSpeechEnabled(isWebChatSpeechEnabled?.applyValue({ args0 -> args0 }))
            .isWebchatPreviewEnabled(isWebchatPreviewEnabled?.applyValue({ args0 -> args0 }))
            .siteName(siteName.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 }))
            .trustedOrigins(trustedOrigins?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DirectLineSiteArgs].
 */
@PulumiTagMarker
public class DirectLineSiteArgsBuilder internal constructor() {
    private var appId: Output<String>? = null

    private var eTag: Output<String>? = null

    private var isBlockUserUploadEnabled: Output<Boolean>? = null

    private var isDetailedLoggingEnabled: Output<Boolean>? = null

    private var isEnabled: Output<Boolean>? = null

    private var isEndpointParametersEnabled: Output<Boolean>? = null

    private var isNoStorageEnabled: Output<Boolean>? = null

    private var isSecureSiteEnabled: Output<Boolean>? = null

    private var isV1Enabled: Output<Boolean>? = null

    private var isV3Enabled: Output<Boolean>? = null

    private var isWebChatSpeechEnabled: Output<Boolean>? = null

    private var isWebchatPreviewEnabled: Output<Boolean>? = null

    private var siteName: Output<String>? = null

    private var tenantId: Output<String>? = null

    private var trustedOrigins: Output<List<String>>? = null

    /**
     * @param value DirectLine application id
     */
    @JvmName("kphlqpswhadokpvg")
    public suspend fun appId(`value`: Output<String>) {
        this.appId = value
    }

    /**
     * @param value Entity Tag
     */
    @JvmName("yajxdcjcjmqryadd")
    public suspend fun eTag(`value`: Output<String>) {
        this.eTag = value
    }

    /**
     * @param value Whether this site is enabled for block user upload.
     */
    @JvmName("bwdbcktcrqyjckcw")
    public suspend fun isBlockUserUploadEnabled(`value`: Output<Boolean>) {
        this.isBlockUserUploadEnabled = value
    }

    /**
     * @param value Whether this site is disabled detailed logging for
     */
    @JvmName("jtpajvbvhialthqv")
    public suspend fun isDetailedLoggingEnabled(`value`: Output<Boolean>) {
        this.isDetailedLoggingEnabled = value
    }

    /**
     * @param value Whether this site is enabled for DirectLine channel
     */
    @JvmName("mxutnytbwplvssah")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Whether this site is EndpointParameters enabled for channel
     */
    @JvmName("padkbsqroxytibam")
    public suspend fun isEndpointParametersEnabled(`value`: Output<Boolean>) {
        this.isEndpointParametersEnabled = value
    }

    /**
     * @param value Whether this no-storage site is disabled detailed logging for
     */
    @JvmName("sxodcqbrfjipvijb")
    public suspend fun isNoStorageEnabled(`value`: Output<Boolean>) {
        this.isNoStorageEnabled = value
    }

    /**
     * @param value Whether this site is enabled for authentication with Bot Framework.
     */
    @JvmName("yaqlqqtdpvdwbiui")
    public suspend fun isSecureSiteEnabled(`value`: Output<Boolean>) {
        this.isSecureSiteEnabled = value
    }

    /**
     * @param value Whether this site is enabled for Bot Framework V1 protocol.
     */
    @JvmName("wxwwsfmatekjskgm")
    public suspend fun isV1Enabled(`value`: Output<Boolean>) {
        this.isV1Enabled = value
    }

    /**
     * @param value Whether this site is enabled for Bot Framework V3 protocol.
     */
    @JvmName("uuoqieamlhgmcbto")
    public suspend fun isV3Enabled(`value`: Output<Boolean>) {
        this.isV3Enabled = value
    }

    /**
     * @param value Whether this site is enabled for Webchat Speech
     */
    @JvmName("oeeoojrjdsjtllpv")
    public suspend fun isWebChatSpeechEnabled(`value`: Output<Boolean>) {
        this.isWebChatSpeechEnabled = value
    }

    /**
     * @param value Whether this site is enabled for preview versions of Webchat
     */
    @JvmName("dmtdcoqcrgwludav")
    public suspend fun isWebchatPreviewEnabled(`value`: Output<Boolean>) {
        this.isWebchatPreviewEnabled = value
    }

    /**
     * @param value Site name
     */
    @JvmName("aelbxgaeiahqfaii")
    public suspend fun siteName(`value`: Output<String>) {
        this.siteName = value
    }

    /**
     * @param value Tenant Id
     */
    @JvmName("vgbpjddltxdqhgxo")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value List of Trusted Origin URLs for this site. This field is applicable only if isSecureSiteEnabled is True.
     */
    @JvmName("erclaiojbmrweljt")
    public suspend fun trustedOrigins(`value`: Output<List<String>>) {
        this.trustedOrigins = value
    }

    @JvmName("hggorggagjiqverf")
    public suspend fun trustedOrigins(vararg values: Output<String>) {
        this.trustedOrigins = Output.all(values.asList())
    }

    /**
     * @param values List of Trusted Origin URLs for this site. This field is applicable only if isSecureSiteEnabled is True.
     */
    @JvmName("qxeslqycsanvhpkg")
    public suspend fun trustedOrigins(values: List<Output<String>>) {
        this.trustedOrigins = Output.all(values)
    }

    /**
     * @param value DirectLine application id
     */
    @JvmName("csclumbclxxdkier")
    public suspend fun appId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.appId = mapped
    }

    /**
     * @param value Entity Tag
     */
    @JvmName("pevgpvamettphoal")
    public suspend fun eTag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eTag = mapped
    }

    /**
     * @param value Whether this site is enabled for block user upload.
     */
    @JvmName("kopmswnrlcgxrars")
    public suspend fun isBlockUserUploadEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isBlockUserUploadEnabled = mapped
    }

    /**
     * @param value Whether this site is disabled detailed logging for
     */
    @JvmName("jdhksinunrorcpxr")
    public suspend fun isDetailedLoggingEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isDetailedLoggingEnabled = mapped
    }

    /**
     * @param value Whether this site is enabled for DirectLine channel
     */
    @JvmName("sotfpjgpwolxpxbn")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value Whether this site is EndpointParameters enabled for channel
     */
    @JvmName("bqlamkrjnpyfthqp")
    public suspend fun isEndpointParametersEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEndpointParametersEnabled = mapped
    }

    /**
     * @param value Whether this no-storage site is disabled detailed logging for
     */
    @JvmName("ojeiojovnmcbethx")
    public suspend fun isNoStorageEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isNoStorageEnabled = mapped
    }

    /**
     * @param value Whether this site is enabled for authentication with Bot Framework.
     */
    @JvmName("xitxhrdallmpfqfh")
    public suspend fun isSecureSiteEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isSecureSiteEnabled = mapped
    }

    /**
     * @param value Whether this site is enabled for Bot Framework V1 protocol.
     */
    @JvmName("hxgkvjgmsvhewucf")
    public suspend fun isV1Enabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isV1Enabled = mapped
    }

    /**
     * @param value Whether this site is enabled for Bot Framework V3 protocol.
     */
    @JvmName("iedsmejuarbeswuw")
    public suspend fun isV3Enabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isV3Enabled = mapped
    }

    /**
     * @param value Whether this site is enabled for Webchat Speech
     */
    @JvmName("oqiemdjkyhntfibo")
    public suspend fun isWebChatSpeechEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isWebChatSpeechEnabled = mapped
    }

    /**
     * @param value Whether this site is enabled for preview versions of Webchat
     */
    @JvmName("vmagrsevnjhvhsva")
    public suspend fun isWebchatPreviewEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isWebchatPreviewEnabled = mapped
    }

    /**
     * @param value Site name
     */
    @JvmName("dbafbvkglpavvxep")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.siteName = mapped
    }

    /**
     * @param value Tenant Id
     */
    @JvmName("wpxowdqpslewomxp")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    /**
     * @param value List of Trusted Origin URLs for this site. This field is applicable only if isSecureSiteEnabled is True.
     */
    @JvmName("liorvtfdlwosovuh")
    public suspend fun trustedOrigins(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustedOrigins = mapped
    }

    /**
     * @param values List of Trusted Origin URLs for this site. This field is applicable only if isSecureSiteEnabled is True.
     */
    @JvmName("levwwpjfeskuuhvf")
    public suspend fun trustedOrigins(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trustedOrigins = mapped
    }

    internal fun build(): DirectLineSiteArgs = DirectLineSiteArgs(
        appId = appId,
        eTag = eTag,
        isBlockUserUploadEnabled = isBlockUserUploadEnabled,
        isDetailedLoggingEnabled = isDetailedLoggingEnabled,
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
        isEndpointParametersEnabled = isEndpointParametersEnabled,
        isNoStorageEnabled = isNoStorageEnabled,
        isSecureSiteEnabled = isSecureSiteEnabled,
        isV1Enabled = isV1Enabled ?: throw PulumiNullFieldException("isV1Enabled"),
        isV3Enabled = isV3Enabled ?: throw PulumiNullFieldException("isV3Enabled"),
        isWebChatSpeechEnabled = isWebChatSpeechEnabled,
        isWebchatPreviewEnabled = isWebchatPreviewEnabled,
        siteName = siteName ?: throw PulumiNullFieldException("siteName"),
        tenantId = tenantId,
        trustedOrigins = trustedOrigins,
    )
}
